@@ -6,6 +6,7 @@
  *
  * Copyright (c) 1999, Alex Roberts
  * Copyright (c) 2003, Roland Stigge <stigge@antcom.de>
+ * Copyright (c) 2005 Marco Tulio Gontijo e Silva <mtgontijo@yahoo.com.br>
  *
  * GTick is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -92,6 +93,36 @@ int gui_get_meter(metro_t* metro) {
   return meter;
 }
 
+/*
+ * Generates the tempo names
+ */
+
+static char* get_tempo_name(gdouble bpm)
+{
+  if (bpm < 40)
+    return "Larghissimo";
+  if (bpm >= 40 && bpm < 60)
+    return "Largo";
+  if (bpm >= 60 && bpm < 66)
+    return "Larghetto";
+  if (bpm >= 66 && bpm < 76)
+    return "Adagio";
+  if (bpm >= 76 && bpm <= 108)
+    return "Andante";
+  if (bpm >= 108 && bpm <= 120)
+    return "Moderato";
+  if (bpm >= 120 && bpm <= 168)
+    return "Allegro";
+  if (bpm >= 168 && bpm < 208)
+    return "Presto";
+  /* if (bpm >= 208) */
+    return "Prestissimo";
+  /*
+   * Numbers collected from wikipedia, with some adjustments.
+   * http://en.wikipedia.org/wiki/Tempo
+   */
+}
+
 /*
  * GUI volume change callback
  */
@@ -125,6 +156,8 @@ static void set_speed_cb(metro_t *metro)
   comm_client_query(metro->inter_thread_comm,
                     MESSAGE_TYPE_SET_FREQUENCY,
 		    frequency);
+
+  gtk_label_set_text(GTK_LABEL(metro->tempo_name), get_tempo_name(*frequency * 60.0));
 }
 
 /*
@@ -1228,15 +1261,20 @@ metro_t* metro_new(void) {
   gtk_container_add(GTK_CONTAINER(metroframe), metrovbox);
   gtk_widget_show(metrovbox);
 
-  table = gtk_table_new(2, 3, FALSE);
+  table = gtk_table_new(3, 3, FALSE);
   gtk_box_pack_start_defaults(GTK_BOX(metrovbox), table);
   gtk_table_set_row_spacings(GTK_TABLE(table), 10);
   gtk_table_set_col_spacings(GTK_TABLE(table), 10);
   gtk_widget_show(table);
   
+  metro->tempo_name = gtk_label_new(get_tempo_name(DEFAULT_BPM));
+  gtk_table_attach_defaults(GTK_TABLE(table), metro->tempo_name,
+                            0, 3, 0, 1);
+  gtk_widget_show(metro->tempo_name);
+
   label = gtk_label_new(_("Speed:"));
   gtk_table_attach(GTK_TABLE(table), label,
-                   0, 1, 0, 1,
+                   0, 1, 1, 2,
 		   GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 0);
   gtk_misc_set_alignment(GTK_MISC(label), 1, 0.5);
   gtk_widget_show (label);
@@ -1251,11 +1289,11 @@ metro_t* metro_new(void) {
   set_speed_cb(metro);
 
   scale = gtk_hscale_new (GTK_ADJUSTMENT (metro->speed_adjustment));
-  gtk_range_set_update_policy (GTK_RANGE (scale), GTK_UPDATE_CONTINUOUS);
+  gtk_range_set_increments(GTK_RANGE (scale), 1.0, 1.0);
   gtk_scale_set_digits (GTK_SCALE (scale), 1);
   gtk_scale_set_draw_value (GTK_SCALE (scale), FALSE);
   gtk_table_attach(GTK_TABLE(table), scale,
-                   1, 2, 0, 1,
+                   1, 2, 1, 2,
 		   GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 0);
   gtk_widget_show (scale);
 
@@ -1263,7 +1301,7 @@ metro_t* metro_new(void) {
                                    1.0, /* Step */
 				   1    /* number of decimals */);
   gtk_table_attach(GTK_TABLE(table), spinbutton,
-                   2, 3, 0, 1,
+                   2, 3, 1, 2,
 		   GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 0);
   gtk_widget_show(spinbutton);
 
@@ -1301,7 +1339,7 @@ metro_t* metro_new(void) {
   
   label = gtk_label_new (_("Volume:"));
   gtk_table_attach(GTK_TABLE(table), label,
-                   0, 1, 1, 2,
+                   0, 1, 2, 3,
 		   GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 0);
   gtk_misc_set_alignment(GTK_MISC(label), 1, 0.5);
   gtk_widget_show (label);
@@ -1319,7 +1357,7 @@ metro_t* metro_new(void) {
   gtk_scale_set_digits (GTK_SCALE (scale), 0);
   gtk_scale_set_draw_value (GTK_SCALE (scale), FALSE);
   gtk_table_attach(GTK_TABLE(table), scale,
-                   1, 2, 1, 2,
+                   1, 2, 2, 3,
 		   GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 0);
   gtk_widget_show (scale);
   
@@ -1327,7 +1365,7 @@ metro_t* metro_new(void) {
                                    1.0, /* Step */
 				   1    /* number of decimals */);
   gtk_table_attach(GTK_TABLE(table), spinbutton,
-                   2, 3, 1, 2,
+                   2, 3, 2, 3,
 		   GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 0);
   gtk_widget_show(spinbutton);
   
